mpa.ProfileMutrate — mpathic 0.0.1 documentation

# mpa.ProfileMutrate

Overview

It is often useful to compute the mutation rate within a set of sequences, e.g., in order to validate the composition of a library. This can be accomplished using the profile mut class as follows:

Usage

    >>> import mpathic as mpa
    >>> mpa.profile_mut(dataset_df = valid_dataset)

Example Input:

    ct                     seq

    259  TAATGTGAGTTAGCTCACTCAT
    41  TAAAGTGAGTTAGCTCACTCAT
    36  TAATGTGAGTAAGCTCACTCAT
    35  TAGTGTGAGTTAGCTCACTCAT
    34  TAATGTTAGTTAGCTCACTCAT
    34  TTATGTGAGTTAGCTCACTCAT
    ...

Example Output:

        pos wt      mut

    0     0  T  0.23819
    1     1  A  0.24141
    2     2  A  0.24118
    3     3  T  0.24016
    4     4  G  0.24093
    5     5  T  0.24001
    ...

## Class Details

class `mpathic.src.profile_mut.` `ProfileMut`(dataset_df=None, bin=None, start=0, end=None, err=False)

  Parameters: | dataset_df: (pandas dataframe) Input data frame containing a valid dataset. bin: (int) A bin number specifying which counts to use start: (int) An integer specifying the sequence start position end: (int) An integer specifying the sequence end position err: (boolean) If true, include error estimates in computed mutual information
  Returns: | mut_df: (pandas data frame) A pandas dataframe containing results.